@@ -25,7 +25,3 @@ regions,userId,aws_session_token):
         client.upload_file(file_name,bucket_name,object_name)
     except:
         print('Failed to export to S3')
-
-send_request_to_s3('clouday1','758325631830','AKIA3BD523NLASPC5PAH',
-'dMXRMkcuUw+YZ6ZDUNyh+HZTROCUt+qNy0Y8j/QZ', ["us-west-2"], '12345678',
-'')
\ No newline at end of file
