@@ -17,13 +17,16 @@ def upload_to_S3(region):
         print('Failed to export to S3')
 
 
-def write_to_dynamo_db(region,account_id):
+def write_to_dynamo_db(region,requestID):
     client=boto3.client('dynamodb',region_name=region)
     item_dict={
-        'account_id':{'S':account_id},
         'status': {'S':'COMPLETED'},
         'data_name': {'S':object_name},
         'timestamp': {'S':str(datetime.datetime.now())}
     }
-    client.put_item(TableName='architecture',
+    
+    client.update_item(TableName='architectureDB',
+    Key={
+        'requestID':{'S':requestID}
+    },
     Item=item_dict)
